@@ -1915,14 +1915,7 @@ def network02(df, entity1, entity2, relation):
     return got_net.show("Tonylab_networks.html")
 
 
-
-
-# >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
-# Test area (update by 2021/4/26):==============================================
-# df=pd.read_csv('C:/Users/lx379/Python_Tony/tony_lab/showcase_data/network.csv')
-# network02(df, 'entity1', 'entity2', 'relation')
-
-
+# polynomial regression equation.
 def polynominalreg(df,x_parameter,y_parameter,M,title):
 
     import numpy as np
@@ -1996,20 +1989,16 @@ def polynominalreg(df,x_parameter,y_parameter,M,title):
     plt.legend(loc='upper right')
     plt.title(title)
     plt.grid(which='both', color='grey', linestyle='--', alpha=0.6)
+    plt.xlabel(output)
     # return p_lsq
     plt.show()
-#     plt.savefig("pics\polynomialreg_demo.png")
-
-
-
-# import pandas as pd
-# df=pd.read_csv('C:/Users/lx379/Python_Tony/tony_lab/showcase_data/pol_reg.csv')
-#
-#
-# polynominalreg(df,'para-1','para-2',9,'demo')
 
 
 
+# >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
+# Test area (update by 2021/4/26):==============================================
+# df=pd.read_csv('C:/Users/lx379/Python_Tony/tony_lab/showcase_data/network.csv')
+# network02(df, 'entity1', 'entity2', 'relation')
 
 
 this_is_nothing = 'Below modules are not validated.---------------------👇'
